@@ -7,7 +7,7 @@ user=`whoami`
 sudo vmdebootstrap \
  --owner ${user} --verbose \
  --size 3G \
- --mirror http://http.debian.net/debian \
+ --mirror http://httpredir.debian.org/debian \
  --log cubietruck.log --log-level debug \
  --arch armhf \
  --foreign /usr/bin/qemu-arm-static \
